---
name: Spec
about: An official specification for enhancements
title: "[Spec]  "
labels: spec
---

# [ The feature ] 


# API Changes


## [ Class ]


### Properties


### Events
 
 
# Scenarios


## C# Example


## XAML Example


## CSS Example


# Backward Compatibility

*Minimum API levels* 
*Breaking changes:*
*Unsupported platforms*


# Difficulty : [ low/medium/high ]
